@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,25 +8,26 @@
 #include "akregatorconfig.h"
 #include "akregatorconfigurepluginlistwidget.h"
 #include <KAboutData>
-#include <KPluginFactory>
 #include <KLocalizedString>
-#include <PimCommon/ConfigurePluginsWidget>
+#include <KPluginFactory>
 #include <PimCommon/ConfigurePluginsListWidget>
+#include <PimCommon/ConfigurePluginsWidget>
 #include <QHBoxLayout>
 using namespace Akregator;
 
-K_PLUGIN_FACTORY(KCMAkregatorPluginsConfigFactory, registerPlugin<KCMAkregatorPluginsConfig>();
-                 )
+K_PLUGIN_FACTORY(KCMAkregatorPluginsConfigFactory, registerPlugin<KCMAkregatorPluginsConfig>();)
 
 KCMAkregatorPluginsConfig::KCMAkregatorPluginsConfig(QWidget *parent, const QVariantList &args)
     : KCModule(parent, args)
 {
-    auto *lay = new QHBoxLayout(this);
-    lay->setContentsMargins(0, 0, 0, 0);
+    auto lay = new QHBoxLayout(this);
+    lay->setContentsMargins({});
 
     KAboutData *about = new KAboutData(QStringLiteral("kcmakrpluginsconfig"),
                                        i18n("Configure Plugins"),
-                                       QString(), QString(), KAboutLicense::GPL,
+                                       QString(),
+                                       QString(),
+                                       KAboutLicense::GPL,
                                        i18n("(c), 2016-2020 Laurent Montel"));
 
     about->addAuthor(i18n("Laurent Montel"), QString(), QStringLiteral("montel@kde.org"));
