@@ -12,9 +12,10 @@
 #include "akregatorinterfaces_export.h"
 
 class QString;
-class QStringList;
+#include <QStringList>
 
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATORINTERFACES_EXPORT FeedListManagementInterface
 {
 public:
