@@ -9,8 +9,8 @@
 #ifndef AKREGATOR_ARTICLELISTVIEW_H
 #define AKREGATOR_ARTICLELISTVIEW_H
 
-#include "akregatorpart_export.h"
 #include "abstractselectioncontroller.h"
+#include "akregatorpart_export.h"
 
 #include <QPointer>
 #include <QSortFilterProxyModel>
@@ -22,17 +22,18 @@
 class QContextMenuEvent;
 template<class T> class QList;
 
-namespace Akregator {
+namespace Akregator
+{
 class Article;
 
-namespace Filters {
+namespace Filters
+{
 }
 
 class AKREGATORPART_EXPORT FilterDeletedProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-
     explicit FilterDeletedProxyModel(QObject *parent = nullptr);
 
 private:
@@ -43,18 +44,17 @@ class AKREGATORPART_EXPORT SortColorizeProxyModel : public QSortFilterProxyModel
 {
     Q_OBJECT
 public:
-
     explicit SortColorizeProxyModel(QObject *parent = nullptr);
 
     Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-    void setFilters(const std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher> > &);
+    void setFilters(const std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher>> &);
 
 private:
     bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const override;
 
     QIcon m_keepFlagIcon;
-    std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher> > m_matchers;
+    std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher>> m_matchers;
 
     QColor m_unreadColor;
     QColor m_newColor;
@@ -65,32 +65,31 @@ class AKREGATORPART_EXPORT ArticleListView : public QTreeView, public ArticleLis
     Q_OBJECT
 
 public:
-
     explicit ArticleListView(QWidget *parent = nullptr);
     ~ArticleListView() override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     void setArticleModel(Akregator::ArticleModel *model) override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     QItemSelectionModel *articleSelectionModel() const override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     const QAbstractItemView *itemView() const override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     QAbstractItemView *itemView() override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     Q_REQUIRED_RESULT QPoint scrollBarPositions() const override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     void setScrollBarPositions(const QPoint &p) override;
 
-    //impl ArticleLister
-    void setFilters(const std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher> > &) override;
+    // impl ArticleLister
+    void setFilters(const std::vector<QSharedPointer<const Akregator::Filters::AbstractMatcher>> &) override;
 
-    //impl ArticleLister
+    // impl ArticleLister
     void forceFilterUpdate() override;
 
     void setIsAggregation(bool isAggregation) override;
@@ -140,13 +139,11 @@ private Q_SLOTS:
 
 private:
     void generalPaletteChanged();
-    enum ColumnMode {
-        GroupMode, FeedMode
-    };
+    enum ColumnMode { GroupMode, FeedMode };
     ColumnMode m_columnMode;
     QColor mTextColor;
     QPointer<SortColorizeProxyModel> m_proxy;
-    std::vector<QSharedPointer<const Filters::AbstractMatcher> > m_matchers;
+    std::vector<QSharedPointer<const Filters::AbstractMatcher>> m_matchers;
     QByteArray m_feedHeaderState;
     QByteArray m_groupHeaderState;
 };
