@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,22 +7,25 @@
 #ifndef ARTICLEVIEWERWEBENGINEWIDGETNG_H
 #define ARTICLEVIEWERWEBENGINEWIDGETNG_H
 
-#include <QWidget>
 #include "akregator_export.h"
 #include "articleviewerwebengine.h"
+#include <QWidget>
 class QPrinter;
 class KActionCollection;
 
-namespace KPIMTextEdit {
+namespace KPIMTextEdit
+{
 class SlideContainer;
 class TextToSpeechWidget;
 }
 
-namespace WebEngineViewer {
+namespace WebEngineViewer
+{
 class FindBarWebEngineView;
 }
 
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATOR_EXPORT ArticleViewerWebEngineWidgetNg : public QWidget
 {
     Q_OBJECT
@@ -45,11 +48,11 @@ private Q_SLOTS:
     void slotExportHtmlPageSuccess(const QString &filename);
     void slotExportHtmlPageFailed();
     void slotHandlePagePrinted(bool result);
+
 private:
     void initializeActions(KActionCollection *ac);
     void initializeLayout(KActionCollection *ac);
     void printRequested(QWebEnginePage *page);
-    void slotRestorePosition();
     WebEngineViewer::FindBarWebEngineView *mFindBarWebView = nullptr;
     ArticleViewerWebEngine *mArticleViewerNg = nullptr;
     KPIMTextEdit::TextToSpeechWidget *mTextToSpeechWidget = nullptr;
