@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,16 +8,13 @@
 #define CRASHWIDGET_H
 
 #include <QWidget>
-namespace Akregator {
+namespace Akregator
+{
 class CrashWidget : public QWidget
 {
     Q_OBJECT
 public:
-    enum CrashAction {
-        RestoreSession = 0,
-        NotRestoreSession,
-        AskMeLater
-    };
+    enum CrashAction { RestoreSession = 0, NotRestoreSession, AskMeLater };
 
     explicit CrashWidget(QWidget *parent = nullptr);
     ~CrashWidget();
