@@ -1,12 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "mainframe.h"
-#include "articleviewerwidget.h"
 #include "articleviewer-ng/webengine/articleviewerwebenginewidgetng.h"
+#include "articleviewerwidget.h"
 
 #include <QGridLayout>
 
@@ -16,8 +16,8 @@ MainFrame::MainFrame(QWidget *parent, QWidget *visibleWidget)
     : Frame(parent)
 {
     setRemovable(false);
-    auto *layout = new QGridLayout(this);
-    layout->setContentsMargins(0, 0, 0, 0);
+    auto layout = new QGridLayout(this);
+    layout->setContentsMargins({});
     layout->addWidget(visibleWidget, 0, 0);
 }
 
