@@ -9,12 +9,13 @@
 #ifndef AKREGATOR_TEMPORARYVALUE_H
 #define AKREGATOR_TEMPORARYVALUE_H
 
-namespace Akregator {
-template<typename T>
-class TemporaryValue
+namespace Akregator
+{
+template<typename T> class TemporaryValue
 {
 public:
-    TemporaryValue(T &var_, const T &tempVal) : var(var_)
+    TemporaryValue(T &var_, const T &tempVal)
+        : var(var_)
         , prev(var)
     {
         var = tempVal;
