@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -28,8 +28,7 @@ Akregator::AkregatorCentralWidget::~AkregatorCentralWidget()
 
 bool AkregatorCentralWidget::previousSessionCrashed() const
 {
-    KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig,
-                   QStandardPaths::AppDataLocation);
+    KConfig config(QStringLiteral("crashed"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
     KConfigGroup configGroup(&config, "Part");
 
     if (!configGroup.readEntry("crashed", false)) {
