@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef AKREGATORCENTRALWIDGET_H
 #define AKREGATORCENTRALWIDGET_H
 
-#include <QStackedWidget>
 #include "crashwidget/crashwidget.h"
-namespace Akregator {
+#include <QStackedWidget>
+namespace Akregator
+{
 class MainWidget;
 class AkregatorCentralWidget : public QStackedWidget
 {
