@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -65,7 +65,7 @@ void StatusSearchLine::initializeActions()
 void StatusSearchLine::showMenu()
 {
     QMenu p(this);
-    auto *grp = new QActionGroup(this);
+    auto grp = new QActionGroup(this);
     grp->setExclusive(true);
     for (int i = AllArticles; i <= ImportantArticles; ++i) {
         auto status = static_cast<StatusSearchLine::Status>(i);
